@@ -789,11 +789,12 @@ class ClusterExecutor(RealExecutor):
 
             waitfiles_parameter = format(
                 "--wait-for-files-file {wait_for_files_file}",
-                wait_for_files_file=wait_for_files_file,
+                wait_for_files_file=repr(wait_for_files_file),
             )
         else:
             waitfiles_parameter = format(
-                "--wait-for-files {wait_for_files}", wait_for_files=wait_for_files
+                "--wait-for-files {wait_for_files}",
+                wait_for_files=[repr(f) for f in wait_for_files],
             )
 
         format_p = partial(
@@ -1072,7 +1073,7 @@ class GenericClusterExecutor(ClusterExecutor):
         success = "success"
         failed = "failed"
         running = "running"
-        status_cmd_kills = set()
+        status_cmd_kills = []
         if self.statuscmd is not None:
 
             def job_status(job, valid_returns=["running", "success", "failed"]):
@@ -1092,7 +1093,7 @@ class GenericClusterExecutor(ClusterExecutor):
                         # snakemake.
                         # Snakemake will handle the signal in
                         # the main process.
-                        status_cmd_kills.add(e.returncode)
+                        status_cmd_kills.append(-e.returncode)
                         if len(status_cmd_kills) > 10:
                             logger.info(
                                 "Cluster status command {} was killed >10 times with signal(s) {} "
