@@ -11,10 +11,8 @@ import sys
 import os
 import json
 import threading
-import tempfile
 from functools import partial
 import inspect
-import traceback
 import textwrap
 
 from snakemake.common import DYNAMIC_FILL
@@ -128,10 +126,10 @@ class WMSLogger:
         workflow will already be running and it would not be worth stopping it.
         """
 
-        from snakemake.resources import parse_resources
+        from snakemake.resources import DefaultResources
 
         self.address = address or "http:127.0.0.1:5000"
-        self.args = parse_resources(args) or []
+        self.args = map(DefaultResources.decode_arg, args) if args else []
         self.metadata = metadata or {}
 
         # A token is suggested but not required, depends on server
